@@ -5,7 +5,7 @@ requires `shtab` to be installed.
 import sys
 import logging
 
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 
 from pydantic_cli import __version__
 from pydantic_cli import run_and_exit, DefaultConfig
@@ -17,16 +17,11 @@ log = logging.getLogger(__name__)
 
 class Options(BaseModel):
     class Config(ExampleConfigDefaults, DefaultConfig):
-        CLI_EXTRA_OPTIONS = {
-            "max_records": ("-m",),
-            "min_filter_score": ("-f",),
-            "input_file": ("-i",),
-        }
         CLI_SHELL_COMPLETION_ENABLE = HAS_AUTOCOMPLETE_SUPPORT
 
-    input_file: str
-    min_filter_score: float
-    max_records: int = 10
+    input_file: str = Field(..., cli=("-i", "--input"))
+    min_filter_score: float = Field(..., cli=("-f", "--filter-score"))
+    max_records: int = Field(10, cli=("-m", "--max-records"))
 
 
 def example_runner(opts: Options) -> int:
